@@ -15,13 +15,13 @@
 # limitations under the License.
 import importlib
 import os
-import sys
 import warnings
 
 import click
 
 from rqsdk.const import TAG_MAP, VERSION_MAP
-from rqsdk.script_update import pip_install, update_bash_file
+from rqsdk.license_helper import format_rqdatac_uri, license_console, print_rqdata_info, set_to_environ, verify_uri
+from rqsdk.script_update import pip_install
 
 
 @click.group()
@@ -40,67 +40,25 @@ def license(rqdatac_uri):
     """配置 license 到环境变量"""
     warnings.filterwarnings("ignore", message="rqdatac is already inited. Settings will be changed.")
 
-    def _print_rqdata_info(uri):
-        import rqdatac
-        from rqdatac.share.errors import AuthenticationFailed
-        try:
-            rqdatac.init(uri=uri)
-            _info = rqdatac.user.get_quota()
-            click.echo("=" * 20)
-            click.echo("license={uri}".format(uri=os.environ.get('RQDATAC2_CONF')))
-            if _info['bytes_limit'] == 0:
-                click.echo("该 license 无流量限制".format(_info['bytes_limit'] / 2 ** 10))
-            else:
-                click.echo("流量限制={}KB".format(_info['bytes_limit'] / 2 ** 10))
-                click.echo("剩余流量={}KB".format((_info['bytes_limit'] - _info['bytes_used']) / 2 ** 10))
-            click.echo("该 license 剩余有效天数为={}".format(_info['remaining_days']))
-            click.echo("=" * 20)
-        except AuthenticationFailed as r:
-            click.echo("=" * 20)
-            click.echo("登录失败，该 license 或用户无法用于初始化 rqdatac\n{}".format(uri))
-            click.echo("请联系商务或技术支持")
-            click.echo("=" * 20)
-            return False
-        return True
-
     if rqdatac_uri == "info":
         uri = os.environ.get('RQDATAC2_CONF')
         if uri is None:
-            click.echo("当前环境没有配置license")
+            click.echo("当前环境没有配置 license ")
         else:
-            _print_rqdata_info(uri)
+            print_rqdata_info(uri)
         return
 
-    while True:
-        if not rqdatac_uri:
-            uri = os.environ.get('RQDATAC2_CONF')
-            if uri is None:
-                click.echo("当前环境没有配置license")
-                rqdatac_uri = None
-            else:
-                _print_rqdata_info(uri)
-        if rqdatac_uri:
-            from rqsdk.utils import init_rqdatac_env
-            if ":" not in rqdatac_uri:
-                rqdatac_uri = "license:{}".format(rqdatac_uri)
-            init_rqdatac_env(rqdatac_uri)
-            rqdatac_uri = os.environ['RQDATAC2_CONF']
-
-            if _print_rqdata_info(rqdatac_uri):
-                if sys.platform.startswith("win"):
-                    os.popen("setx RQDATAC2_CONF {uri} ".format(uri=rqdatac_uri))
-                else:
-                    update_bash_file(rqdatac_uri)
-                click.echo("当前 license 已设置为 {uri}".format(uri=rqdatac_uri))
-                click.echo("请重启当前的 terminal ".format(uri=rqdatac_uri))
-                return
-        click.echo('如需修改请按照【用户名:密码】的格式输入您的用户名密码或直接键入license key。')
-        click.echo('不更改则按 Enter 键退出')
-        rqdatac_uri = input()
-        click.echo()
-        if not rqdatac_uri:
+    elif rqdatac_uri != "":
+        rqdatac_uri = format_rqdatac_uri(rqdatac_uri)
+        if verify_uri(rqdatac_uri):
+            print_rqdata_info(rqdatac_uri)
+            set_to_environ(rqdatac_uri)
             return
 
+    rqdatac_uri = rqdatac_uri or os.environ.get('RQDATAC2_CONF')
+    license_console(rqdatac_uri)
+    return
+
 
 @cli.command()
 @click.argument('product', default="", nargs=1)
